@@ -4,7 +4,7 @@ function(x, param=rc9.fund, scaled=TRUE){
     stop("param must be a list")
   if(sum(is.na(match(names(param),names(rc9.fund))))!=0)
     stop("param must be a list with correct names, see for example rc9.fund")
-  y<-param$a1*exp(-param$alpha1*x)+param$a2*exp(-param$alpha2*(x-param$mu2)-exp(-param$lambda*(x-param$mu2)))+param$c
-  if(scaled==TRUE) y<-y/sum(y)
-  y
+  m<-param$a1*exp(-param$alpha1*x)+param$a2*exp(-param$alpha2*(x-param$mu2)-exp(-param$lambda*(x-param$mu2)))+param$c
+  if(scaled==TRUE) m<-m/sum(m)
+  m
 }
